@@ -1,5 +1,5 @@
 #include "da.h"
 
 gint       prog_fd;
-gchar      gtkrc_tmp[1024];
+gchar     *gtkrc_tmp;
 GtkWidget *preview_socket;
