@@ -17,7 +17,7 @@ extern "C" {
 
 GNode *read_directory (gchar *directory);
 void merge_nodes (GNode *node1, GNode *node2);
-GtkWidget *generate_tree ();
+GtkWidget *generate_tree (void);
 gint button_press (GtkCTree *ctree, GdkEventButton *event, gpointer data);
 
 typedef enum
